@@ -1,10 +1,10 @@
-/* $Id: log-vbox.cpp 122708 2018-05-18 13:20:51Z aleksey $ */
+/* $Id: log-vbox.cpp 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * VirtualBox Runtime - Logging configuration.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -153,7 +153,7 @@
 
 #include <VBox/log.h>
 #include <iprt/asm.h>
-#include <iprt/err.h>
+#include <iprt/errcore.h>
 #include <iprt/time.h>
 #ifdef IN_RING3
 # include <iprt/param.h>
