@@ -1,10 +1,10 @@
-/* $Id: handletable.cpp 118412 2017-10-17 14:26:02Z bird $ */
+/* $Id: handletable.cpp 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * IPRT - Handle Tables.
  */
 
 /*
- * Copyright (C) 2008-2017 Oracle Corporation
+ * Copyright (C) 2008-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -33,7 +33,7 @@
 
 #include <iprt/mem.h>
 #include <iprt/spinlock.h>
-#include <iprt/err.h>
+#include <iprt/errcore.h>
 #include <iprt/assert.h>
 #include <iprt/param.h>
 #include <iprt/string.h>
