@@ -1,10 +1,10 @@
-/* $Id: thread.cpp 136786 2020-04-01 12:40:26Z bird $ */
+/* $Id: thread.cpp 127855 2019-01-01 01:45:53Z bird $ */
 /** @file
  * IPRT - Threads, common routines.
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -657,14 +657,12 @@ DECLHIDDEN(void) rtThreadTerminate(PRTTHREADINT pThread, int rc)
 {
     Assert(pThread->cRefs >= 1);
 
+#ifdef IPRT_WITH_GENERIC_TLS
     /*
      * Destroy TLS entries.
      */
-#ifdef IPRT_WITH_GENERIC_TLS
     rtThreadTlsDestruction(pThread);
-#elif defined(RT_OS_WINDOWS) && defined(IN_RING3)
-    rtThreadWinTlsDestruction();
-#endif
+#endif /* IPRT_WITH_GENERIC_TLS */
 
     /*
      * Set the rc, mark it terminated and signal anyone waiting.
